package repository

import "be.ems/src/modules/monitor/model"

// IMonitor 监控服务资源相关信息 数据接口
type IMonitor interface {
	// CreateMonitorBase 创建监控_基本信息
	CreateMonitorBase(m model.MonitorBase) error

	// DelMonitorBase 删除监控_基本信息
	DelMonitorBase(ltTime int64) error

	// SelectMonitorBase 查询监控_基本信息
	SelectMonitorBase(query map[string]any) []model.MonitorBase

	// BatchCreateMonitorIO 批量创建监控_IO
	BatchCreateMonitorIO(ioList []model.MonitorIO) error

	// DelMonitorIO 删除监控_IO
	DelMonitorIO(ltTime int64) error

	// SelectMonitorIO 查询监控_IO
	SelectMonitorIO(query map[string]any) []model.MonitorIO

	// BatchCreateMonitorNet 批量创建监控_网络
	BatchCreateMonitorNet(netList []model.MonitorNetwork) error

	// DelMonitorNet 删除监控_网络
	DelMonitorNet(ltTime int64) error

	// SelectMonitorNetwork 查询监控_网络
	SelectMonitorNetwork(query map[string]any) []model.MonitorNetwork
}
